@@ -1,5 +1,7 @@
 `FILT.SEISN` <-
-function(TH, sel=1:length(TH$JSTR), FILT=list(ON=TRUE, fl=0.5, fh=7.0, type="HP", proto="BU", RM=FALSE, zp=TRUE ), TAPER=0.1, POSTTAPER=0.1)
+    function(TH, sel=1:length(TH$JSTR), FILT=list(ON=TRUE, fl=0.5, fh=7.0, type="HP",
+                                                  proto="BU", RM=FALSE, zp=TRUE ), TAPER=0.1,
+             POSTTAPER=0.1, AUGMENT=FALSE )
   {
     ###  TH = seismic structure
     ###  sel = vector of selected time series in structure
@@ -39,18 +41,30 @@ function(TH, sel=1:length(TH$JSTR), FILT=list(ON=TRUE, fl=0.5, fh=7.0, type="HP"
 
         if(!is.null(TAPER)) { ry = applytaper(ry, p=TAPER) }
 
-        fy = butfilt(ry, fl=FILT$fl, fh=FILT$fh , deltat=dt, type=FILT$type , proto=FILT$proto, npoles=FILT$npoles, RM=FILT$RM, zp=FILT$zp   )
+        Fhi = FILT$fh
+        Fnyq = 1/(2*dt) 
+
+        if( Fhi > Fnyq )  { Fhi = Fnyq }
+
+        if(AUGMENT){
+            fy = AUGMENTbutfilt(ry, fl=FILT$fl, fh=Fhi , deltat=dt, type=FILT$type ,
+                            proto=FILT$proto, npoles=FILT$npoles, RM=FILT$RM, zp=FILT$zp   )
+        }
+        else{
+            fy = butfilt(ry, fl=FILT$fl, fh=Fhi , deltat=dt, type=FILT$type ,
+                         proto=FILT$proto, npoles=FILT$npoles, RM=FILT$RM, zp=FILT$zp   )
         ## ex = dt*0:(length(y)-1)
         ##  plot(ex, fy, type='l')
         if(!is.null(POSTTAPER)) { fy = applytaper(fy, p=POSTTAPER) }
-        
+        }
         NEWH$JSTR[[ii]][!ny] =  fy
         
       }
 
     NEWH$filter = FILT
 
-    proc = paste(sep=" ", "FILT.SEISN", FILT$fl, FILT$fh, FILT$type, FILT$proto, TAPER, POSTTAPER) 
+      proc = paste(sep=" ", "FILT.SEISN", FILT$fl, FILT$fh, FILT$type,
+                   FILT$proto, TAPER, POSTTAPER) 
    NEWH$process =  c(NEWH$process, proc)
     
     invisible(NEWH)
