@@ -12,7 +12,7 @@ doGABOR.MTM<-function(Xamp, DT = 0.008, ppoint=95, multi = 1, scale.def =0, TWIN
   
   gridon = FALSE
   TPALS = c("rainbow", "topo.colors", "terrain.colors", "heat.colors", "tomo.colors")
-  pal = Gcols(plow=5, phi=0,  N=100, pal=TPALS[1])
+  pal = RPMG::Gcols(plow=5, phi=0,  N=100, pal=TPALS[1])
 
 
   fl=0
